/* menu.cpp
 * Draws and deals with the menus... pretty simple
 * Licensed under the Open Software License version 2.0
 * coded by ReKleSS [rekless@fastmail.fm]
 */

#include "ss.h"
#include <SDL.h>
#include <GL/gl.h>
#include <string.h>
#include "text.h"

#define DIR_DOWN 0
#define DIR_UP 1

SDL_Rect play;
SDL_Rect quit;
SDL_Rect *curItem;

extern GLuint textures[12];
extern bool keys[256];
extern int state;
extern GLint shipList;
bool whacked[256];
extern Text text;

void initMenu()
{
	FILE *data;
	char fullpath[64];

	strcpy(fullpath, basePath);
	strcat(fullpath, "gfx/menubg.dat");
	printf("%s\n", fullpath);
	data = fopen(fullpath, "r");
	if (data == NULL) {
		printf("Couldn't find menu data\n");
	}

	fscanf(data, "Play: %ix%i %ix%i\nQuit: %ix%i %ix%i",
	       (int *) &play.x, (int *) &play.y, (int *) &play.w,
	       (int *) &play.h, (int *) &quit.x, (int *) &quit.y,
	       (int *) &quit.w, (int *) &quit.h);
	fclose(data);
	curItem = &play;
	memset(&whacked, 0, sizeof(bool) * 256);
}

void mDrawScene()
{

	glDisable(GL_DEPTH_TEST);
	glMatrixMode(GL_MODELVIEW);
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	glLoadIdentity();
	glColor3f(1.0f, 1.0f, 1.0f);
	glTranslatef(0.0f, 0.0f, -0.84f);
	glBindTexture(GL_TEXTURE_2D, textures[10]);
	glBegin(GL_QUADS);
	glTexCoord2f(0, 1);
	glVertex2f(-1.0f, -1.0f);
	glTexCoord2f(1, 1);
	glVertex2f(1.0f, -1.0f);
	glTexCoord2f(1, 0);
	glVertex2f(1.0f, 1.0f);
	glTexCoord2f(0, 0);
	glVertex2f(-1.0f, 1.0f);
	glEnd();

	//handle keystrokes
	if (keys[KEY_DOWN] && !whacked[KEY_DOWN]) {
		curItem++;
		if (curItem > &quit)
			curItem = &play;
		whacked[KEY_DOWN] = true;
	} else if (!keys[KEY_DOWN] && whacked[KEY_DOWN])
		whacked[KEY_DOWN] = false;

	if (keys[KEY_UP] && !whacked[KEY_UP]) {
		curItem--;
		if (curItem < &play)
			curItem = &quit;
		whacked[KEY_UP] = true;
	} else if (!keys[KEY_UP] && whacked[KEY_UP])
		whacked[KEY_UP] = false;

	if (keys[KEY_JUMP]) {	//we got a space; figure out wtf the user wants
		if (curItem == &play) {
			state = GAME;
			memset(&keys, 0, sizeof(bool) * 256);	//zero the key array
			return;
		} else if (curItem == &quit) {
			SDL_Event quitEvent;
			quitEvent.type = SDL_QUIT;
			SDL_PushEvent(&quitEvent);
		}
	}

	glTranslatef(0.0f, 0.0f, 0.01f);
	glDisable(GL_TEXTURE_2D);
	glColor4f(1.0f, 1.0f, 1.0f, 0.5f);
	glEnable(GL_BLEND);

	glBegin(GL_QUADS);
	glVertex2f((curItem->x / 256.0f) - 1.0f,
		   -((curItem->h / 128.0f) - 1.0f));
	glVertex2f((curItem->w / 256.0f) - 1.0f,
		   -((curItem->h / 128.0f) - 1.0f));
	glVertex2f((curItem->w / 256.0f) - 1.0f,
		   -((curItem->y / 128.0f) - 1.0f));
	glVertex2f((curItem->x / 256.0f) - 1.0f,
		   -((curItem->y / 128.0f) - 1.0f));
	glEnd();

	glEnable(GL_TEXTURE_2D);
	glDisable(GL_BLEND);

	glBindTexture(GL_TEXTURE_2D, textures[0]);
	glTranslatef(4.0f, -4.0f, -5.0f);
	glRotatef(135.0f, 0.0f, 1.0f, 0.0f);
	glEnable(GL_DEPTH_TEST);
	glCallList(shipList);

	glDisable(GL_BLEND);
	SDL_GL_SwapBuffers();
}
